@@ -1,8 +1,11 @@
 import logging
 
 from django.db import models
+from django.utils.functional import cached_property
 from django.utils.translation import gettext_lazy as _
 
+from easy_thumbnails.VIL import Image as VILImage
+
 from .. import settings as filer_settings
 from ..utils.compatibility import PILImage
 from ..utils.filer_easy_thumbnails import FilerThumbnailer
@@ -26,24 +29,55 @@ class BaseImage(File):
     file_type = 'Image'
     _icon = "image"
 
-    _height = models.IntegerField(null=True, blank=True)
-    _width = models.IntegerField(null=True, blank=True)
+    _height = models.FloatField(
+        null=True,
+        blank=True,
+    )
 
-    default_alt_text = models.CharField(_('default alt text'), max_length=255, blank=True, null=True)
-    default_caption = models.CharField(_('default caption'), max_length=255, blank=True, null=True)
+    _width = models.FloatField(
+        null=True,
+        blank=True,
+    )
+
+    default_alt_text = models.CharField(
+        _("default alt text"),
+        max_length=255,
+        blank=True,
+        null=True,
+    )
+
+    default_caption = models.CharField(
+        _("default caption"),
+        max_length=255,
+        blank=True,
+        null=True,
+    )
+
+    subject_location = models.CharField(
+        _("subject location"),
+        max_length=64,
+        blank=True,
+        default='',
+    )
 
-    subject_location = models.CharField(_('subject location'), max_length=64, blank=True,
-                                        default='')
     file_ptr = models.OneToOneField(
-        to='filer.File', parent_link=True,
+        to='filer.File',
+        parent_link=True,
         related_name='%(app_label)s_%(class)s_file',
         on_delete=models.CASCADE,
     )
 
+    class Meta:
+        app_label = 'filer'
+        verbose_name = _("image")
+        verbose_name_plural = _("images")
+        abstract = True
+        default_manager_name = 'objects'
+
     @classmethod
     def matches_file_type(cls, iname, ifile, mime_type):
         # source: https://www.freeformatter.com/mime-types-list.html
-        image_subtypes = ['gif', 'jpeg', 'png', 'x-png']
+        image_subtypes = ['gif', 'jpeg', 'png', 'x-png', 'svg+xml']
         maintype, subtype = mime_type.split('/')
         return maintype == 'image' and subtype in image_subtypes
 
@@ -56,7 +90,10 @@ class BaseImage(File):
                 except ValueError:
                     imgfile = self.file_ptr.file
                 imgfile.seek(0)
-                self._width, self._height = PILImage.open(imgfile).size
+                if self.mime_type == 'image/svg+xml':
+                    self._width, self._height = VILImage.load(imgfile).size
+                else:
+                    self._width, self._height = PILImage.open(imgfile).size
                 imgfile.seek(0)
             except Exception:
                 if post_init is False:
@@ -80,16 +117,12 @@ class BaseImage(File):
         else:
             return 1.0
 
-    def _get_exif(self):
-        if hasattr(self, '_exif_cache'):
-            return self._exif_cache
-        else:
-            if self.file:
-                self._exif_cache = get_exif_for_file(self.file)
-            else:
-                self._exif_cache = {}
-        return self._exif_cache
-    exif = property(_get_exif)
+    @cached_property
+    def exif(self):
+        try:
+            return get_exif_for_file(self.file)
+        except Exception:
+            return {}
 
     def has_edit_permission(self, request):
         return self.has_generic_permission(request, 'edit')
@@ -126,11 +159,11 @@ class BaseImage(File):
 
     @property
     def width(self):
-        return self._width or 0
+        return self._width or 0.0
 
     @property
     def height(self):
-        return self._height or 0
+        return self._height or 0.0
 
     def _generate_thumbnails(self, required_thumbnails):
         _thumbnails = {}
@@ -171,10 +204,3 @@ class BaseImage(File):
             thumbnail_storage=self.file.thumbnail_storage,
             thumbnail_basedir=self.file.thumbnail_basedir)
         return tn
-
-    class Meta:
-        app_label = 'filer'
-        verbose_name = _('image')
-        verbose_name_plural = _('images')
-        abstract = True
-        default_manager_name = 'objects'
