@@ -1,13 +1,26 @@
 'use strict';
 /* global django */
 
+// as of Django 2.x we need to check where jQuery is
+var djQuery = window.$;
+
+if (django.jQuery) {
+    djQuery = django.jQuery;
+}
+
 (function ($) {
+    function windowname_to_id(text) {
+        text = text.replace(/__dot__/g, '.');
+        text = text.replace(/__dash__/g, '-');
+        return text.split('__')[0];
+    }
+
     window.dismissPopupAndReload = function (win) {
         document.location.reload();
         win.close();
     };
     window.dismissRelatedImageLookupPopup = function (win, chosenId, chosenThumbnailUrl, chosenDescriptionTxt) {
-        var id = window.windowname_to_id(win.name);
+        var id = windowname_to_id(win.name);
         var lookup = $('#' + id);
         var container = lookup.closest('.filerFile');
         var image = container.find('.thumbnail_img');
@@ -20,9 +33,10 @@
         element.val(chosenId);
         element.closest('.js-filer-dropzone').addClass('js-object-attached');
         image.attr('src', chosenThumbnailUrl).removeClass('hidden');
+        image.removeAttr('srcset');  // would be nicer, but much more complicate to also replace 'srcset'
         descriptionText.text(chosenDescriptionTxt);
         clearer.removeClass('hidden');
-        lookup.addClass('hidden');
+        lookup.addClass('related-lookup-change');
         dropzoneMessage.addClass('hidden');
 
         if (oldId !== chosenId) {
@@ -31,7 +45,7 @@
         win.close();
     };
     window.dismissRelatedFolderLookupPopup = function (win, chosenId, chosenName) {
-        var id = window.windowname_to_id(win.name);
+        var id = windowname_to_id(win.name);
         var clearButton = $('#id_' + id + '_clear');
         var input = $('#id_' + id);
         var folderName = $('#id_' + id + '_description_txt');
@@ -43,4 +57,4 @@
         addFolderButton.addClass('hidden');
         win.close();
     };
-})(django.jQuery);
+})(djQuery);
