@@ -6,7 +6,7 @@ from . import views
 
 urlpatterns = [
     re_path(
-        filer_settings.FILER_CANONICAL_URL + r'(?P<uploaded_at>[0-9]+)/(?P<file_id>[0-9]+)/$',  # flake8: noqa
+        filer_settings.FILER_CANONICAL_URL + r'(?P<uploaded_at>[0-9]+)/(?P<file_id>[0-9]+)/$',
         views.canonical,
         name='canonical'
     ),
